# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Parallel-Runner
Version:	0.014
Release:	1.%{__distinit}%{__distvers}
Summary:	An object to manage running things in parallel processes
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Parallel-Runner
Source0:	https://cpan.metacpan.org/authors/id/E/EX/EXODIST/Parallel-Runner-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Child) >= 0.009
BuildRequires:	perl(POSIX)
BuildRequires:	perl(strict)
BuildRequires:	perl(Time::HiRes)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Test2::IPC)
BuildRequires:	perl(Test2::V0)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
There are several other modules to do this, you probably want one of them. This
module exists as a super-specialized parallel task manager. You create the
object with a process limit and callbacks for what to do while waiting for a
free process slot, as well as a callback for what a process should do just
before exiting.

You must explicitly call $runner->finish() when you are done. If the runner is
destroyed before its children are finished, a warning will be generated and
your child processes will be killed, by force if necessary.

If you specify a maximum of 1 then no forking will occur, and run() will block
until the coderef returns. You can force a fork by providing a boolean true
value as the second argument to run(), which will force the runner to fork
before running the coderef; however, run() will still block until the child
exits.

%prep
%setup -q -n Parallel-Runner-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
RUN_KILL_TESTS=1 make test

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Parallel/
%{_mandir}/man3/Parallel::Runner.3*

%changelog
* Fri Apr 26 2024 Paul Howarth <paul@city-fan.org> - 0.014-1
- Update to 0.014
  - Move to Dist::Zilla
  - Switch to Test2::V0

* Mon Apr 10 2023 Paul Howarth <paul@city-fan.org> - 0.013-30
- Use SPDX-format license tag
- Use https:// source URL
- Avoid use of deprecated patch syntax

* Wed Jun  5 2019 Paul Howarth <paul@city-fan.org> - 0.013-18
- Perl 5.30 rebuild

* Thu Apr 19 2018 Paul Howarth <paul@city-fan.org> - 0.013-14
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workarounds for building with Test::More < 0.88

* Thu Sep 15 2016 Paul Howarth <paul@city-fan.org> - 0.013-10
- Classify buildreqs by usage
- Drop %%defattr, redundant since rpm 4.4

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 0.013-6
- Drop %%defattr, redundant since rpm 4.4

* Thu Aug 15 2013 Paul Howarth <paul@city-fan.org> - 0.013-2
- Enable the optional "kill" tests

* Wed Aug 14 2013 Paul Howarth <paul@city-fan.org> - 0.013-1
- Initial RPM version
